@@ -2,10 +2,20 @@ setClass("SpatialPointsMeteorology", slots = list(dates = "Date", data="vector")
 setClass("SpatialPointsTopography", contains="SpatialPointsDataFrame")
 setClass("SpatialGridMeteorology", slots = list(dates = "Date", data="vector"), contains="SpatialGrid")
 setClass("SpatialGridTopography", contains="SpatialGridDataFrame")
+setClass("SpatialPixelsMeteorology", slots = list(dates = "Date", data="vector"), contains="SpatialPixels")
+setClass("SpatialPixelsTopography", contains="SpatialPixelsDataFrame")
 
+setMethod("spplot", signature("SpatialPixelsMeteorology"), definition=
+            function(obj, date, variable="MeanTemperature", ...) {
+              sgd = SpatialPixelsDataFrame(points=obj@coords, grid = obj@grid, data=obj@data[[date]], 
+                                           proj4string= obj@proj4string)
+              spplot(sgd, variable, ...)
+            }
+)
 setMethod("spplot", signature("SpatialGridMeteorology"), definition=
             function(obj, date, variable="MeanTemperature", ...) {
-              sgd = SpatialGridDataFrame(obj@grid, obj@data[[date]], obj@proj4string)
+              sgd = SpatialGridDataFrame(grid = obj@grid, data=obj@data[[date]], 
+                                         proj4string=obj@proj4string)
               spplot(sgd, variable, ...)
             }
 )
@@ -28,6 +38,25 @@ setMethod("spplot", signature("SpatialGridTopography"), definition =
               }
             }
 )
+setMethod("spplot", signature("SpatialPixelsTopography"), definition =
+            function(obj, variable="elevation",...) {
+              if(variable=="elevation") {
+                spplot(as(obj,"SpatialPixelsDataFrame"), zcol = "elevation",
+                       col.regions = topo.colors,...)
+              } else if(variable=="slope") {
+                spplot(as(obj,"SpatialPixelsDataFrame"), zcol = "slope",
+                       ...)
+              } else if(variable=="aspect") {
+                spplot(as(obj,"SpatialPixelsDataFrame"), zcol = "aspect",
+                       col.regions = colorRampPalette(c("black","green","red","blue", "black")),
+                       at = seq(0,360, by=5),...)
+              } else if(variable=="N-S") {
+                spplot(SpatialPixelsDataFrame(obj@coords, grid=obj@grid, data=data.frame(NS = cos(pi*obj@data$aspect/180))),...)
+              } else if(variable=="E-W") {
+                spplot(SpatialPixelsDataFrame(obj@coords, grid=obj@grid, data=data.frame(EW = sin(pi*obj@data$aspect/180))),...)
+              }
+            }
+)
 
 setMethod("[", signature("SpatialPointsMeteorology"),definition =
   function (x, i, j, ..., drop = TRUE) 
